@@ -197,7 +197,13 @@ class OpenEVSE:
 
         async with aiohttp.ClientSession() as session:
             http_method = getattr(session, method)
-            async with http_method(url, data=data, auth=auth) as resp:
+            _LOGGER.debug(
+                "Connecting to %s with data payload of %s using method %s",
+                url,
+                data,
+                method,
+            )
+            async with http_method(url, json=data, auth=auth) as resp:
                 try:
                     message = await resp.json()
                 except TimeoutError:
@@ -206,7 +212,7 @@ class OpenEVSE:
                     message = {"msg": resp}
 
                 if resp.status == 400:
-                    _LOGGER.error("%s", message["msg"])
+                    _LOGGER.error("Error 400: %s", message["msg"])
                     raise ParseJSONError
                 if resp.status == 401:
                     error = await resp.text()
@@ -430,7 +436,7 @@ class OpenEVSE:
         else:
             # Older firmware use RAPI commands
             _LOGGER.debug("Toggling manual override via RAPI")
-            command = "$FE" if self._status["state"] == "sleeping" else "$FS"
+            command = "$FE" if self._status["state"] == 254 else "$FS"
             response = await self.send_command(command)
             _LOGGER.debug("Toggle response: %s", response[1])
 
@@ -442,6 +448,40 @@ class OpenEVSE:
         response = await self.process_request(url=url, method="delete")
         _LOGGER.debug("Toggle response: %s", response["msg"])
 
+    async def set_current(self, amps: int = 6) -> None:
+        """Set the soft current limit."""
+        #   3.x - 4.1.0: use RAPI commands $SC <amps>
+        #   4.1.2: use HTTP API call
+        amps = int(amps)
+        cutoff = AwesomeVersion("4.1.2")
+        current = AwesomeVersion(self._config["version"])
+
+        if cutoff <= current:
+            url = f"{self.url}config"
+
+            if (
+                amps < self._config["min_current_hard"]
+                or amps > self._config["max_current_hard"]
+            ):
+                _LOGGER.error("Invalid value for max_current_soft: %s", amps)
+                raise ValueError
+
+            data = {"max_current_soft": amps}
+
+            _LOGGER.debug("Setting max_current_soft to %s", amps)
+            response = await self.process_request(
+                url=url, method="post", data=data
+            )  # noqa: E501
+            if response["msg"] != "done":
+                _LOGGER.error("Problem issuing command: %s", response["msg"])
+                raise UnknownError
+        else:
+            # RAPI commands
+            _LOGGER.debug("Setting current via RAPI")
+            command = f"$SC {amps}"
+            response = await self.send_command(command)
+            _LOGGER.debug("Set current response: %s", response[1])
+
     @property
     def hostname(self) -> str:
         """Return charger hostname."""
@@ -597,6 +637,8 @@ class OpenEVSE:
     def current_capacity(self) -> int:
         """Return the current capacity."""
         assert self._status is not None
+        if self._config is not None and "max_current_soft" in self._config:
+            return self._config["max_current_soft"]
         return self._status["pilot"]
 
     @property
@@ -724,14 +766,25 @@ class OpenEVSE:
         assert self._status is not None
         return self._status["divert_active"]
 
+    @property
+    def wifi_serial(self) -> str | None:
+        """Return wifi serial."""
+        if self._config is not None and "wifi_serial" in self._config:
+            return self._config["wifi_serial"]
+        return None
+
     # There is currently no min/max amps JSON data
     # available via HTTP API methods
     @property
     def min_amps(self) -> int:
         """Return the minimum amps."""
+        if self._config is not None and "min_current_hard" in self._config:
+            return self._config["min_current_hard"]
         return MIN_AMPS
 
     @property
     def max_amps(self) -> int:
         """Return the maximum amps."""
+        if self._config is not None and "max_current_hard" in self._config:
+            return self._config["max_current_hard"]
         return MAX_AMPS
